from pathlib import Path

import idliveface

IDLIVEFACE_HOME = Path(r"/opt/idliveface")


def process_result(result):
    print(f"Result: {result}")

    if result.status != idliveface.FaceStatus.INVALID:
        print(f"Image is {result.status}, probability is {result.genuine_probability}")
    else:
        print("Image did not pass validations and is not suitable for analysis")
        print(f"Failed validations: {result.failed_validations}")


def main():
    blueprint = idliveface.Blueprint(IDLIVEFACE_HOME / "data")

    print("Initializing...")
    decoder = blueprint.create_image_decoder()
    analyzer = blueprint.create_face_analyzer()

    print("\nAnalyzing real_face.jpg")
    image = decoder.decode_file(IDLIVEFACE_HOME / "examples/images/real_face.jpg")
    result = analyzer.analyze(image)
    process_result(result)

    print("\nAnalyzing spoof_face.jpg")
    image = decoder.decode_file(IDLIVEFACE_HOME / "examples/images/spoof_face.jpg")
    result = analyzer.analyze(image)
    process_result(result)

    print("\nAnalyzing face_is_occluded.jpg")
    image = decoder.decode_file(IDLIVEFACE_HOME / "examples/images/face_is_occluded.jpg")
    result = analyzer.analyze(image)
    process_result(result)


if __name__ == "__main__":
    main()
